@@ -113,36 +113,38 @@ impl Default for Config {
     fn default() -> Config {
         use termion::event::Key::*;
         Config {
-            config: hashmap!{
-                Esc => Action::UnselectRet,
-                PageUp => Action::ScrollUp,
-                PageDown => Action::ScrollDown,
-                Delete => Action::DeleteSelected,
-                Up => Action::SelectUp,
-                Down => Action::SelectDown,
-                Left => Action::SelectLeft,
-                Right => Action::SelectRight,
-                Backspace => Action::EraseChar,
-                Char('\n') => Action::CreateSibling,
-                Char('\t') => Action::CreateChild,
-                Ctrl('n') => Action::CreateFreeNode,
-                Ctrl('k') => Action::ExecSelected,
-                Ctrl('w') => Action::DrillDown,
-                Ctrl('q') => Action::PopUp,
-                Ctrl('f') => Action::PrefixJump,
-                Ctrl('a') => Action::ToggleCompleted,
-                Ctrl('h') => Action::ToggleHideCompleted,
-                Ctrl('r') => Action::Arrow,
-                Ctrl('p') => Action::Arrange,
-                Ctrl('z') => Action::AutoArrange,
-                Ctrl('t') => Action::ToggleCollapsed,
-                Ctrl('c') => Action::Quit,
-                Ctrl('x') => Action::Save,
-                Ctrl('l') => Action::ToggleShowLogs,
-                Ctrl('e') => Action::EnterCmd,
-                Ctrl('v') => Action::FindTask,
-                Ctrl('y') => Action::YankPasteNode,
-            },
+            config: vec![
+                (Esc, Action::UnselectRet),
+                (PageUp, Action::ScrollUp),
+                (PageDown, Action::ScrollDown),
+                (Delete, Action::DeleteSelected),
+                (Up, Action::SelectUp),
+                (Down, Action::SelectDown),
+                (Left, Action::SelectLeft),
+                (Right, Action::SelectRight),
+                (Backspace, Action::EraseChar),
+                (Char('\n'), Action::CreateSibling),
+                (Char('\t'), Action::CreateChild),
+                (Ctrl('n'), Action::CreateFreeNode),
+                (Ctrl('k'), Action::ExecSelected),
+                (Ctrl('w'), Action::DrillDown),
+                (Ctrl('q'), Action::PopUp),
+                (Ctrl('f'), Action::PrefixJump),
+                (Ctrl('a'), Action::ToggleCompleted),
+                (Ctrl('h'), Action::ToggleHideCompleted),
+                (Ctrl('r'), Action::Arrow),
+                (Ctrl('p'), Action::Arrange),
+                (Ctrl('z'), Action::AutoArrange),
+                (Ctrl('t'), Action::ToggleCollapsed),
+                (Ctrl('c'), Action::Quit),
+                (Ctrl('x'), Action::Save),
+                (Ctrl('l'), Action::ToggleShowLogs),
+                (Ctrl('e'), Action::EnterCmd),
+                (Ctrl('v'), Action::FindTask),
+                (Ctrl('y'), Action::YankPasteNode),
+            ]
+                .into_iter()
+                .collect(),
         }
     }
 }
